require 'spec_helper'

describe "User Authorizations" do
  describe "a 'guest' role" do
    before do
      @user                      = User.create(:name => Faker::Name.name,
                                               :password => 'testing',
                                               :password_confirmation => "testing",
                                               :email => Faker::Internet.email)
      Authorization.current_user = @user
    end

    describe "should be allowed" do
      it "to access the 'index' action" do
        should_be_allowed_to(:index, :users)
      end

      it "to access the 'show' action" do
        should_be_allowed_to(:show, :users)
      end

      it "to access the 'new' action" do
        should_be_allowed_to(:new, :users)
      end

      it "to access the 'create' action" do
        should_be_allowed_to(:create, :users)
      end

      it "to access the 'edit' action" do
        should_be_allowed_to(:edit, @user)
      end

      it "to access the 'update' action" do
        should_be_allowed_to(:update, @user)
      end

      it "to access the 'destroy' action" do
        should_be_allowed_to(:destroy, @user)
      end
    end

    describe "should not be allowed" do
      before do
        @alt_user = User.create(:name => Faker::Name.name,
                                :password => 'testing',
                                :password_confirmation => "testing",
                                :email => Faker::Internet.email)
      end
      
      it "to access the 'edit' action for another user" do
        should_not_be_allowed_to(:edit, @alt_user)
      end

      it "to access the 'update' action for another user" do
        should_not_be_allowed_to(:update, @alt_user)
      end

      it "to access the 'destroy' action for another user" do
        should_not_be_allowed_to(:update, @alt_user)
      end
      
      it "to access the 'change_password' action for another user" do
        should_not_be_allowed_to(:change_password, @alt_user)
      end

      it "to access the 'update_password' action for another user" do
        should_not_be_allowed_to(:update_password, @alt_user)
      end
    end
  end

  describe "an 'admin' role" do
    before do
      @user = User.create(:name => Faker::Name.name,
                          :password => 'testing',
                          :password_confirmation => "testing",
                          :email => Faker::Internet.email)
      @user.roles << Role.create(:name => 'admin')
      Authorization.current_user = @user
    end

    describe "should be allowed" do
      it "to access the 'index' action" do
        should_be_allowed_to(:index, :users)
      end

      it "to access the 'show' action" do
        should_be_allowed_to(:show, :users)
      end

      it "to access the 'new' action" do
        should_be_allowed_to(:new, :users)
      end

      it "to access the 'create' action" do
        should_be_allowed_to(:create, :users)
      end

      it "to access the 'edit' action" do
        should_be_allowed_to(:edit, :users)
      end

      it "to access the 'update' action" do
        should_be_allowed_to(:update, :users)
      end

      it "to access the 'destroy' action" do
        should_be_allowed_to(:destroy, :users)
      end
    end
  end
end
