require 'spec_helper'

describe User do
  before do
    @valid_attributes = { :name => Faker::Name.name,
                          :password => 'testing',
                          :password_confirmation => "testing",
                          :email => Faker::Internet.email }
  end

  context "validations" do
    it "should not create a new object with without an email" do
      user = User.new(@valid_attributes.update(:email => ""))
      user.valid?.should be_false
      user.errors[:email].include?("can't be blank").should be_true
    end

    it "should not create a new object with an email less than 6 characters" do
      user = User.new(@valid_attributes.update(:email => "t@m.m"))
      user.valid?.should be_false
      user.errors[:email].include?("is too short (minimum is 6 characters)").should be_true
    end

    it "should not create a new object with an email that does not look like an email" do
      user = User.new(@valid_attributes.update(:email => "testing"))
      user.valid?.should be_false
      user.errors[:email].include?("should look like an email address.").should be_true
    end

    it "should not create a new object without name" do
      user = User.new(@valid_attributes.update(:name => ""))
      user.valid?.should be_false
      user.errors[:name].include?("can't be blank").should be_true
    end

#    it "should not create a new object without role" do
#      user = User.new(@valid_attributes.update(:role => nil))
#      user.valid?.should be_false
#      user.errors[:role_id].include?("can't be blank").should be_true
#    end

    it "should not create a new object with a non-unique email address" do
      User.create(@valid_attributes)
      user = User.new(@valid_attributes)
      user.valid?.should be_false
      user.errors[:email].include?("has already been taken").should be_true
    end
  end

  context "methods" do
    describe "email=(value)" do
      it "should downcase the email attribute" do
        user = User.create(@valid_attributes.update(:email => "AdMiN@EXAMPLE.com"))
        user.email.should == "admin@example.com"
      end
    end

#    describe "role_symbols" do
#      it "should return administrator for an administrator" do
#        user = User.make(:administrator)
#        user.role_symbols.should == [:administrator]
#      end
#    end
  end
end
